pub struct RiSanitizationConfig {
pub trim_whitespace: bool,
pub lowercase: bool,
pub uppercase: bool,
pub remove_extra_spaces: bool,
pub remove_html_tags: bool,
pub escape_special_chars: bool,
}Fields
trim_whitespace: boollowercase: booluppercase: boolremove_extra_spaces: boolescape_special_chars: boolTrait Implementations
Sourceimpl Clone for RiSanitizationConfig
impl Clone for RiSanitizationConfig
Sourcefn clone(&self) -> RiSanitizationConfig
fn clone(&self) -> RiSanitizationConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RiSanitizationConfig
impl Debug for RiSanitizationConfig
Sourceimpl Default for RiSanitizationConfig
impl Default for RiSanitizationConfig
Sourceimpl<'de> Deserialize<'de> for RiSanitizationConfig
impl<'de> Deserialize<'de> for RiSanitizationConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'py> IntoPyObject<'py> for RiSanitizationConfig
impl<'py> IntoPyObject<'py> for RiSanitizationConfig
Sourcetype Target = RiSanitizationConfig
type Target = RiSanitizationConfig
The Python output type
Sourcetype Output = Bound<'py, <RiSanitizationConfig as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <RiSanitizationConfig as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for RiSanitizationConfig
impl PyClass for RiSanitizationConfig
Sourceimpl PyClassImpl for RiSanitizationConfig
impl PyClassImpl for RiSanitizationConfig
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<RiSanitizationConfig>
type ThreadChecker = SendablePyClass<RiSanitizationConfig>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyTypeInfo for RiSanitizationConfig
impl PyTypeInfo for RiSanitizationConfig
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for RiSanitizationConfig
impl Serialize for RiSanitizationConfig
impl DerefToPyAny for RiSanitizationConfig
impl ExtractPyClassWithClone for RiSanitizationConfig